==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/inputs/VolumeGroupMetaDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.inputs

import com.pulumi.azurenative.netapp.inputs.VolumeGroupMetaDataArgs.builder
import com.pulumi.azurenative.netapp.kotlin.enums.ApplicationType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Volume group properties
 * @property applicationIdentifier Application specific identifier
 * @property applicationType Application Type
 * @property deploymentSpecId Application specific identifier of deployment rules for the volume group
 * @property globalPlacementRules Application specific placement rules for the volume group
 * @property groupDescription Group Description
 */
public data class VolumeGroupMetaDataArgs(
    public val applicationIdentifier: Output<String>? = null,
    public val applicationType: Output<Either<String, ApplicationType>>? = null,
    public val deploymentSpecId: Output<String>? = null,
    public val globalPlacementRules: Output<List<PlacementKeyValuePairsArgs>>? = null,
    public val groupDescription: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.netapp.inputs.VolumeGroupMetaDataArgs> {
    override fun toJava(): com.pulumi.azurenative.netapp.inputs.VolumeGroupMetaDataArgs =
        com.pulumi.azurenative.netapp.inputs.VolumeGroupMetaDataArgs.builder()
            .applicationIdentifier(applicationIdentifier?.applyValue({ args0 -> args0 }))
            .applicationType(
                applicationType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .deploymentSpecId(deploymentSpecId?.applyValue({ args0 -> args0 }))
            .globalPlacementRules(
                globalPlacementRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .groupDescription(groupDescription?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VolumeGroupMetaDataArgs].
 */
@PulumiTagMarker
public class VolumeGroupMetaDataArgsBuilder internal constructor() {
    private var applicationIdentifier: Output<String>? = null

    private var applicationType: Output<Either<String, ApplicationType>>? = null

    private var deploymentSpecId: Output<String>? = null

    private var globalPlacementRules: Output<List<PlacementKeyValuePairsArgs>>? = null

    private var groupDescription: Output<String>? = null

    /**
     * @param value Application specific identifier
     */
    @JvmName("aqdythdhloigwfqa")
    public suspend fun applicationIdentifier(`value`: Output<String>) {
        this.applicationIdentifier = value
    }

    /**
     * @param value Application Type
     */
    @JvmName("jrbfepfjxkmlytnc")
    public suspend fun applicationType(`value`: Output<Either<String, ApplicationType>>) {
        this.applicationType = value
    }

    /**
     * @param value Application specific identifier of deployment rules for the volume group
     */
    @JvmName("tixomucpirpedbjd")
    public suspend fun deploymentSpecId(`value`: Output<String>) {
        this.deploymentSpecId = value
    }

    /**
     * @param value Application specific placement rules for the volume group
     */
    @JvmName("kpwfuuafqisqeoug")
    public suspend fun globalPlacementRules(`value`: Output<List<PlacementKeyValuePairsArgs>>) {
        this.globalPlacementRules = value
    }

    @JvmName("fsjhampcjfdrfcrs")
    public suspend fun globalPlacementRules(vararg values: Output<PlacementKeyValuePairsArgs>) {
        this.globalPlacementRules = Output.all(values.asList())
    }

    /**
     * @param values Application specific placement rules for the volume group
     */
    @JvmName("aoinoviymqanjidj")
    public suspend fun globalPlacementRules(values: List<Output<PlacementKeyValuePairsArgs>>) {
        this.globalPlacementRules = Output.all(values)
    }

    /**
     * @param value Group Description
     */
    @JvmName("dwtwrsvnosdakxgu")
    public suspend fun groupDescription(`value`: Output<String>) {
        this.groupDescription = value
    }

    /**
     * @param value Application specific identifier
     */
    @JvmName("xestmtiegtfnlska")
    public suspend fun applicationIdentifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationIdentifier = mapped
    }

    /**
     * @param value Application Type
     */
    @JvmName("qwhtmtgqmovfuyjf")
    public suspend fun applicationType(`value`: Either<String, ApplicationType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationType = mapped
    }

    /**
     * @param value Application Type
     */
    @JvmName("fdnqduagpwmktfqn")
    public fun applicationType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.applicationType = mapped
    }

    /**
     * @param value Application Type
     */
    @JvmName("wppydplsfghrwydl")
    public fun applicationType(`value`: ApplicationType) {
        val toBeMapped = Either.ofRight<String, ApplicationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.applicationType = mapped
    }

    /**
     * @param value Application specific identifier of deployment rules for the volume group
     */
    @JvmName("taonkcjrkktqlgey")
    public suspend fun deploymentSpecId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentSpecId = mapped
    }

    /**
     * @param value Application specific placement rules for the volume group
     */
    @JvmName("vwvrqsdynonobiem")
    public suspend fun globalPlacementRules(`value`: List<PlacementKeyValuePairsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.globalPlacementRules = mapped
    }

    /**
     * @param argument Application specific placement rules for the volume group
     */
    @JvmName("yviguwrypemfkxxp")
    public suspend
    fun globalPlacementRules(argument: List<suspend PlacementKeyValuePairsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PlacementKeyValuePairsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.globalPlacementRules = mapped
    }

    /**
     * @param argument Application specific placement rules for the volume group
     */
    @JvmName("isgywcvlxraitiyj")
    public suspend fun globalPlacementRules(
        vararg
        argument: suspend PlacementKeyValuePairsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            PlacementKeyValuePairsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.globalPlacementRules = mapped
    }

    /**
     * @param argument Application specific placement rules for the volume group
     */
    @JvmName("mluvmkjylxuucksa")
    public suspend
    fun globalPlacementRules(argument: suspend PlacementKeyValuePairsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PlacementKeyValuePairsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.globalPlacementRules = mapped
    }

    /**
     * @param values Application specific placement rules for the volume group
     */
    @JvmName("jwyvvatylsgqjxtu")
    public suspend fun globalPlacementRules(vararg values: PlacementKeyValuePairsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.globalPlacementRules = mapped
    }

    /**
     * @param value Group Description
     */
    @JvmName("kinyvfvajajpdtfw")
    public suspend fun groupDescription(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupDescription = mapped
    }

    internal fun build(): VolumeGroupMetaDataArgs = VolumeGroupMetaDataArgs(
        applicationIdentifier = applicationIdentifier,
        applicationType = applicationType,
        deploymentSpecId = deploymentSpecId,
        globalPlacementRules = globalPlacementRules,
        groupDescription = groupDescription,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/netapp/kotlin/inputs/VolumeGroupMetaDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.netapp.kotlin.inputs

import com.pulumi.azurenative.netapp.inputs.VolumeGroupMetaDataArgs.builder
import com.pulumi.azurenative.netapp.kotlin.enums.ApplicationType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Volume group properties
 * @property applicationIdentifier Application specific identifier
 * @property applicationType Application Type
 * @property deploymentSpecId Application specific identifier of deployment rules for the volume group
 * @property globalPlacementRules Application specific placement rules for the volume group
 * @property groupDescription Group Description
 */
public data class VolumeGroupMetaDataArgs(
    public val applicationIdentifier: Output<String>? = null,
    public val applicationType: Output<Either<String, ApplicationType>>? = null,
    public val deploymentSpecId: Output<String>? = null,
    public val globalPlacementRules: Output<List<PlacementKeyValuePairsArgs>>? = null,
    public val groupDescription: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.netapp.inputs.VolumeGroupMetaDataArgs> {
    override fun toJava(): com.pulumi.azurenative.netapp.inputs.VolumeGroupMetaDataArgs =
        com.pulumi.azurenative.netapp.inputs.VolumeGroupMetaDataArgs.builder()
            .applicationIdentifier(applicationIdentifier?.applyValue({ args0 -> args0 }))
            .applicationType(
                applicationType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .deploymentSpecId(deploymentSpecId?.applyValue({ args0 -> args0 }))
            .globalPlacementRules(
                globalPlacementRules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .groupDescription(groupDescription?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VolumeGroupMetaDataArgs].
 */
@PulumiTagMarker
public class VolumeGroupMetaDataArgsBuilder internal constructor() {
    private var applicationIdentifier: Output<String>? = null

    private var applicationType: Output<Either<String, ApplicationType>>? = null

    private var deploymentSpecId: Output<String>? = null

    private var globalPlacementRules: Output<List<PlacementKeyValuePairsArgs>>? = null

    private var groupDescription: Output<String>? = null

    /**
     * @param value Application specific identifier
     */
    @JvmName("ljfqrjoqrmndwlrg")
    public suspend fun applicationIdentifier(`value`: Output<String>) {
        this.applicationIdentifier = value
    }

    /**
     * @param value Application Type
     */
    @JvmName("oxvqgqyydnpliiij")
    public suspend fun applicationType(`value`: Output<Either<String, ApplicationType>>) {
        this.applicationType = value
    }

    /**
     * @param value Application specific identifier of deployment rules for the volume group
     */
    @JvmName("hvlixppenraphthh")
    public suspend fun deploymentSpecId(`value`: Output<String>) {
        this.deploymentSpecId = value
    }

    /**
     * @param value Application specific placement rules for the volume group
     */
    @JvmName("ccjhcqqmhgdinxol")
    public suspend fun globalPlacementRules(`value`: Output<List<PlacementKeyValuePairsArgs>>) {
        this.globalPlacementRules = value
    }

    @JvmName("kvwgpwbglsmkkhhr")
    public suspend fun globalPlacementRules(vararg values: Output<PlacementKeyValuePairsArgs>) {
        this.globalPlacementRules = Output.all(values.asList())
    }

    /**
     * @param values Application specific placement rules for the volume group
     */
    @JvmName("dtpcqlispnvlfdsu")
    public suspend fun globalPlacementRules(values: List<Output<PlacementKeyValuePairsArgs>>) {
        this.globalPlacementRules = Output.all(values)
    }

    /**
     * @param value Group Description
     */
    @JvmName("xbxfjojwnemyfmuw")
    public suspend fun groupDescription(`value`: Output<String>) {
        this.groupDescription = value
    }

    /**
     * @param value Application specific identifier
     */
    @JvmName("wgmkypttexmpwptp")
    public suspend fun applicationIdentifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationIdentifier = mapped
    }

    /**
     * @param value Application Type
     */
    @JvmName("hasvghawoqsuoikf")
    public suspend fun applicationType(`value`: Either<String, ApplicationType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationType = mapped
    }

    /**
     * @param value Application Type
     */
    @JvmName("xaibpuyodhcovasc")
    public fun applicationType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.applicationType = mapped
    }

    /**
     * @param value Application Type
     */
    @JvmName("nwqhoirslermyidn")
    public fun applicationType(`value`: ApplicationType) {
        val toBeMapped = Either.ofRight<String, ApplicationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.applicationType = mapped
    }

    /**
     * @param value Application specific identifier of deployment rules for the volume group
     */
    @JvmName("kblevfeqrrbwpesh")
    public suspend fun deploymentSpecId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentSpecId = mapped
    }

    /**
     * @param value Application specific placement rules for the volume group
     */
    @JvmName("nfgfmstlahmdbhdq")
    public suspend fun globalPlacementRules(`value`: List<PlacementKeyValuePairsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.globalPlacementRules = mapped
    }

    /**
     * @param argument Application specific placement rules for the volume group
     */
    @JvmName("cewgelsknpatpdhr")
    public suspend
    fun globalPlacementRules(argument: List<suspend PlacementKeyValuePairsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PlacementKeyValuePairsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.globalPlacementRules = mapped
    }

    /**
     * @param argument Application specific placement rules for the volume group
     */
    @JvmName("rnipiswiyacebbgg")
    public suspend fun globalPlacementRules(
        vararg
        argument: suspend PlacementKeyValuePairsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            PlacementKeyValuePairsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.globalPlacementRules = mapped
    }

    /**
     * @param argument Application specific placement rules for the volume group
     */
    @JvmName("grkxdxhioffilonh")
    public suspend
    fun globalPlacementRules(argument: suspend PlacementKeyValuePairsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(PlacementKeyValuePairsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.globalPlacementRules = mapped
    }

    /**
     * @param values Application specific placement rules for the volume group
     */
    @JvmName("qrdnciujerxtodlx")
    public suspend fun globalPlacementRules(vararg values: PlacementKeyValuePairsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.globalPlacementRules = mapped
    }

    /**
     * @param value Group Description
     */
    @JvmName("brgrmsrrwjurhhvy")
    public suspend fun groupDescription(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupDescription = mapped
    }

    internal fun build(): VolumeGroupMetaDataArgs = VolumeGroupMetaDataArgs(
        applicationIdentifier = applicationIdentifier,
        applicationType = applicationType,
        deploymentSpecId = deploymentSpecId,
        globalPlacementRules = globalPlacementRules,
        groupDescription = groupDescription,
    )
}
